@@ -42,6 +42,7 @@ class Scenario:
     j |= {"stoken": self.token, "sfinish": True}
     self.token = None
     self.init = False
+    self.nis = False
     self.cli._send(Scenario._encode_json(j))
 
   def _decide(self, j):
@@ -52,23 +53,33 @@ class Scenario:
     else:
       self._init_scenario(j)
 
-  def send_msg(self, msg):
+  def send_msg(self, msg, last=False):
+    if last:
+      self.nis = True
     j = {"send": msg}
     self._decide(j)
 
-  def send_as_user(self, msg):
+  def send_as_user(self, msg, last=False):
+    if last:
+      self.nis = True
     j = {"send_as_user": msg}
     self._decide(j)
 
-  def send_status(self, msg_id, msg):
+  def send_status(self, msg_id, msg, last=False):
+    if last:
+      self.nis = True
     j = {"send_status": {"id": msg_id, "msg": msg}}
     self._decide(j)
 
-  def send_error(self, msg):
+  def send_error(self, msg, last=False):
+    if last:
+      self.nis = True
     j = {"send_warning": msg}
     self._decide(j)
 
-  def store_cells(self, values_dict):
+  def store_cells(self, values_dict, last=False):
+    if last:
+      self.nis = True
     j = {"store_in_memory": values_dict}
     self._decide(j)
 
@@ -91,9 +102,6 @@ class Scenario:
         raise ScenarioTerminatedException
     return j
 
-  def next_is_last(self):
-    self.nis = True
-
   def wait(self):
     while True:
       msg = self.listen()
@@ -101,4 +109,7 @@ class Scenario:
         continue
       if msg['author'] == 1:
         continue
-      return msg
+      return msg['content']
+
+  def terminate(self):
+    self._terminate_scenario(dict())
