@@ -16,6 +16,9 @@ class Server:
     except ConnectionRefusedError:
       print("Connection refused.")
       return b"{}"
+    except json.decoder.JSONDecodeError:
+      print('JSON decode error.')
+      return b"{}"
   
   def _encode_json(j):
     return json.dumps(j).encode()
